@@ -79,7 +79,7 @@ class Forum(object):
         else:
             posts_before = self.posts(collection_id, folder, None, since_id-1 if since_id else None, 'DESC', 40)[::-1]
             posts_next = self.posts(collection_id, folder, since_id-1 if since_id else None, None, 'ASC', 60)
-            result['last'] = [math.ceil(float(count)/20), last_page[-1].id]
+            result['last'] = [int(math.ceil(float(count)/20)), last_page[-1].id]
             result['posts'] = posts_next[:20]
             tpage = page - 1
             t_off=20
